import { select, csv, scaleLinear, axisLeft, axisBottom, format, extent } from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const circleRadius = 10;


// Factory para crear rectangulos
const render = data => {
  
  // d.acceleration = +d.acceleration;
  // d.cylinders = +d.cylinders;
  // d.horsepower = +d.horsepower;
  // d.mpg = +d.mpg;
  // d.weight = +d.weight;
  // d.year = +d.year;
  
  const title = "Grafico scatter"
  const xValue = d => d.horsepower;
  const xAxisLabel = "Horsepower";
  const yValue = d => d.weight;
	const yAxisLabel = "Weight";
  const margin = {top:40,right:50,bottom:60,left:100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0,innerWidth])
  	.nice();
	
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0,innerHeight])
  	.nice();
  
  const g = svg.append("g")
  	.attr("transform", `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();// Eliminar las lineas del eje X
  
  yAxisG.append('text')
  	.attr("class","axis-label")
  	.attr("x", -innerHeight/2)
  	.attr('text-anchor','middle')
  	.attr("y", -70)
  	.attr("transform", `rotate(-90)`)
  	.attr("fill","black")
  	.text(yAxisLabel);
  
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr("transform", `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr("class","axis-label")
  	.attr("x", innerWidth/2)
  	.attr("y", 50)
  	.attr("fill","black")
  	.text(xAxisLabel);
  
  // Crear círculos para el Scatter
  g.selectAll('circle').data(data)
  	.enter().append("circle")
  		.attr("cy", d => yScale(yValue(d)))
  		.attr("cx", d => xScale(xValue(d)))
  		.attr("r", circleRadius);
  
  g.append('text')
  	.attr("y", -10)
  	.attr("class", "title")
  	.text(title);
}

csv( 'https://vizhub.com/PabloReyesBetanzo/datasets/auto-mpg.csv' ).then(data => {
  // Transformar strings a numeros
  data.forEach(d=>{
    d.acceleration = +d.acceleration;
    d.cylinders = +d.cylinders;
    d.horsepower = +d.horsepower;
    d.mpg = +d.mpg;
    d.weight = +d.weight;
    d.year = +d.year;
  });
  render(data);
}